@@ -115,7 +115,9 @@ class HouseMapper(ObjectMapper):
         'mun_parent_obj_id': 'hierarchy__mun__parentobjid__objectid',
         'mun_parent_guid': 'hierarchy__mun__parentobjid__objectguid',
         'number': 'number',
-        'house_type': 'house_type',
+        'house_type': 'housetype__shortname',
+        'building_type': 'addtype1__shortname',
+        'structure_type': 'addtype2__shortname',
     }
 
     assert set(fields_map) == set(House.fields)
