@@ -119,7 +119,7 @@ Ext.m3.gar.AddressFields = Ext.extend(Ext.Component, {
                 if (this.place.postalCode) {
                     this.zipCodeField.setValue(this.place.postalCode);
                 }
-                if (!self.street) {
+                if (!this.street) {
                     this.updateFullAddress();
                 }
                 this.placeNameField.un('render', setValue);
@@ -156,7 +156,8 @@ Ext.m3.gar.AddressFields = Ext.extend(Ext.Component, {
                 if (this.street.postalCode) {
                     this.zipCodeField.setValue(this.street.postalCode);
                 }
-                if (!self.house) {
+
+                if (this.hasOwnProperty('house') && !this.house) {
                     this.updateFullAddress();
                 }
                 this.streetNameField.un('render', setValue);
@@ -272,6 +273,8 @@ Ext.m3.gar.AddressFields = Ext.extend(Ext.Component, {
                 this.buildingNumberField,
                 this.structureNumberField,
                 this.houseTypeField,
+                this.buildingTypeField,
+                this.structureTypeField,
             );
         }
 
@@ -675,6 +678,8 @@ Ext.m3.gar.AddressFields = Ext.extend(Ext.Component, {
         this.houseIDField.setValue(record.get('objectId'));
 
         this.houseTypeField.setValue(record.get('houseType'));
+        this.buildingTypeField.setValue(record.get('buildingType'));
+        this.structureTypeField.setValue(record.get('structureType'));
 
         if (record.get('houseNumber')) {
             this.houseNumberField.setValue(record.get('houseNumber'));
@@ -1008,10 +1013,10 @@ Ext.m3.gar.AddressViewBase = Ext.extend(Ext.Container, {
                     '{houseType}{houseNumber}',
                 '</tpl>',
                 '<tpl if="buildingNumber">',
-                    ' корп.{buildingNumber}',
+                    ' {buildingType}{buildingNumber}',
                 '</tpl>',
                 '<tpl if="structureNumber">',
-                    ' стр.{structureNumber}</span>',
+                    ' {structureType}{structureNumber}</span>',
                 '</tpl>',
             '</div>',
         '</tpl>'
@@ -1128,21 +1133,21 @@ Ext.m3.gar.RowsAddressView = Ext.extend(Ext.m3.gar.AddressViewBase, {
             this.fields.houseNumberField,
             this.labelsWidth.house,
             {
-                'flex': 0
+                'flex': 1
             }
         );
         this.buildingFieldContainer = this.formed(
             this.fields.buildingNumberField,
             this.labelsWidth.building,
             {
-                'flex': 0
+                'flex': 2
             }
         );
         this.structureFieldContainer = this.formed(
             this.fields.structureNumberField,
             this.labelsWidth.structure,
             {
-                'flex': 0
+                'flex': 1
             }
         );
         rowItems.push(
@@ -1151,6 +1156,8 @@ Ext.m3.gar.RowsAddressView = Ext.extend(Ext.m3.gar.AddressViewBase, {
             this.structureFieldContainer,
             this.fields.houseIDField,
             this.fields.houseTypeField,
+            this.fields.buildingTypeField,
+            this.fields.structureTypeField,
         );
     },
 
