@@ -42,25 +42,25 @@ Ext.override(Ext.m3.gar.AddressFields, {
                 if (this.hasHouseField() && !this.isHouseEmpty()) {
                     if (this.houseNumberField.getValue().indexOf('уч.') > -1) {
                         addressParts.push(
-                         'земельный участок ' + this.houseNumberField.getValue().substring(4)
+                            'земельный участок ' + this.houseNumberField.getValue().substring(4)
                         );
                     }
                     else {
                         addressParts.push(
-                       this.houseTypeField.getValue() + this.houseNumberField.getValue()
+                            this.houseTypeField.getValue() + this.houseNumberField.getValue()
                         );
                     }
                 }
 
                 if (this.hasHouseField() && !this.isBuildingEmpty()) {
                     addressParts.push(
-                        'корп.' + this.buildingNumberField.getValue()
+                        this.buildingTypeField.getValue() + this.buildingNumberField.getValue()
                     );
                 }
 
                 if (this.hasHouseField() && !this.isStructureEmpty()) {
                     addressParts.push(
-                        'стр.' + this.structureNumberField.getValue()
+                        this.structureTypeField.getValue() + this.structureNumberField.getValue()
                     );
                 }
 
@@ -140,7 +140,7 @@ Ext.m3.gar.NewAddressView = Ext.extend(Ext.m3.gar.RowsAddressView, {
             this.fields.buildingNumberField,
             this.labelsWidth.building,
             {
-                'flex': 1
+                'flex': 2
             }
         );
         this.structureFieldContainer = this.formed(
@@ -156,6 +156,8 @@ Ext.m3.gar.NewAddressView = Ext.extend(Ext.m3.gar.RowsAddressView, {
             this.structureFieldContainer,
             this.fields.houseIDField,
             this.fields.houseTypeField,
+            this.fields.buildingTypeField,
+            this.fields.structureTypeField,
         );
     },
 
